select distinct segment_name
from all_rollback_segs
